@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the track.getInfo slice of the LastFM API
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use Moo;
 use strictures 2;
@@ -118,27 +118,35 @@ WebService::LastFM::TrackInfo - Access to the track.getInfo slice of the LastFM
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
   use WebService::LastFM::TrackInfo;
 
   my $w = WebService::LastFM::TrackInfo->new(api_key => 'abcdef123456');
-
   my $r = $w->fetch(
     artist => 'Led Zeppelin',
     track  => 'Kashmir',
   );
   print Dumper $r; # Do something cool with the result!
 
+  $w = WebService::LastFM::TrackInfo->new(
+    api_key => 'abcdef123456',
+    method  => 'album.getInfo',
+  );
+  $r = $w->fetch(
+    artist => 'Led Zeppelin',
+    album  => 'Presence',
+  );
+
 =head1 DESCRIPTION
 
 C<WebService::LastFM::TrackInfo> provides access to the
 L<https://www.last.fm/api/show/track.getInfo> API slice.
 
 This module may also be used to get information about other bits of
-the API, like for an artist, for example.
+the API, like artist or album, for example.
 
 =head1 ATTRIBUTES
 
